Class NSTemplateInfo
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Syntax
Constructors
NSTemplateInfo()
Initializes a new instance of the NSTemplateInfo class.
Declaration
NSTemplateInfo
Methods
GetDescription()
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
String GetDescription()
Returns
| Type | Description |
|---|---|
| String | Document description, shown as a tooltip or in some extended description area. |
Examples
NSTemplateInfo thing;
String description = thing.GetDescription();
GetExternalReference()
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
String GetExternalReference()
Returns
| Type | Description |
|---|---|
| String | Unique key that identifies the document so it can be retrieved. |
Examples
NSTemplateInfo thing;
String externalReference = thing.GetExternalReference();
GetName()
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
String GetName()
Returns
| Type | Description |
|---|---|
| String | Name of the document, shown in lists etc to the user. |
Examples
NSTemplateInfo thing;
String name = thing.GetName();
GetPluginId()
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
Integer GetPluginId()
Returns
| Type | Description |
|---|---|
| Integer | ID of plugin that stores this template, so it can be retrieved. |
Examples
NSTemplateInfo thing;
Integer pluginId = thing.GetPluginId();
SetDescription(String)
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
Void SetDescription(String description)
Parameters
| Type | Name | Description |
|---|---|---|
| String | description | Document description, shown as a tooltip or in some extended description area. |
Returns
| Type | Description |
|---|---|
| Void |
Examples
NSTemplateInfo thing;
String description;
thing.SetDescription(description);
SetExternalReference(String)
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
Void SetExternalReference(String externalReference)
Parameters
| Type | Name | Description |
|---|---|---|
| String | externalReference | Unique key that identifies the document so it can be retrieved. |
Returns
| Type | Description |
|---|---|
| Void |
Examples
NSTemplateInfo thing;
String externalReference;
thing.SetExternalReference(externalReference);
SetName(String)
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
Void SetName(String name)
Parameters
| Type | Name | Description |
|---|---|---|
| String | name | Name of the document, shown in lists etc to the user. |
Returns
| Type | Description |
|---|---|
| Void |
Examples
NSTemplateInfo thing;
String name;
thing.SetName(name);
SetPluginId(Integer)
Information about a document template, i.e., a document that generally contains unresolved merge tags and that is used as the source for creating new documents.
Declaration
Void SetPluginId(Integer pluginId)
Parameters
| Type | Name | Description |
|---|---|---|
| Integer | pluginId | ID of plugin that stores this template, so it can be retrieved. |
Returns
| Type | Description |
|---|---|
| Void |
Examples
NSTemplateInfo thing;
Integer pluginId;
thing.SetPluginId(pluginId);